summaryrefslogtreecommitdiff
path: root/admin
diff options
context:
space:
mode:
authorRob Holland <tigger@gentoo.org>2004-02-07 23:11:12 +0000
committerRob Holland <tigger@gentoo.org>2004-02-07 23:11:12 +0000
commitd698d179d3ce3a4a17f8ca26af445d8c3dde4a16 (patch)
tree3c7e5ed5567626a20f4707c9d3cd1f6c7d6a8074 /admin
parent#38788 - Add "emerge cvs" instructions (diff)
downloadgentoo-d698d179d3ce3a4a17f8ca26af445d8c3dde4a16.tar.gz
gentoo-d698d179d3ce3a4a17f8ca26af445d8c3dde4a16.tar.bz2
gentoo-d698d179d3ce3a4a17f8ca26af445d8c3dde4a16.zip
correct variable names
Diffstat (limited to 'admin')
-rw-r--r--admin/www.gentoo.org/scripts/nightly.sh24
1 files changed, 12 insertions, 12 deletions
diff --git a/admin/www.gentoo.org/scripts/nightly.sh b/admin/www.gentoo.org/scripts/nightly.sh
index 9374321a85..b7c1d48ed7 100644
--- a/admin/www.gentoo.org/scripts/nightly.sh
+++ b/admin/www.gentoo.org/scripts/nightly.sh
@@ -1,7 +1,7 @@
#!/bin/bash
echo ">>> Starting Web update..."
#to get GENTOO_WEB_DOCROOT and WEBSCRIPTS defined
source ~/.bashrc
#to get all arches in our package listing:
@@ -10,26 +10,26 @@ export PORTDIR="$HOME/gentoo-x86"
export FEATURES="-cvs -digest"
[ -z "${GENTOO_WEB_DOCROOT}" ] && echo "\$WEBROOT not set; exiting" && exit 1
-[ -z "${WEBSCRIPTS}" ] && echo "\$WEBSCRIPTS not set; exiting" && exit 1
+[ -z "${GENTOO_WEB_SCRIPTS}" ] && echo "\$GENTOO_WEB_SCRIPTS not set; exiting" && exit 1
-${WEBSCRIPTS}/cvs-page.sh
-${WEBSCRIPTS}/use-index.py
+${GENTOO_WEB_SCRIPTS}/cvs-page.sh
+${GENTOO_WEB_SCRIPTS}/use-index.py
# no idea why the next script was being run, so commenting it out until someone complains
-#${WEBSCRIPTS}/site-archive.sh
-${WEBSCRIPTS}/news-index.sh
+#${GENTOO_WEB_SCRIPTS}/site-archive.sh
+${GENTOO_WEB_SCRIPTS}/news-index.sh
# no idea why the next script was being run, so commenting it out until someone complains
-#${WEBSCRIPTS}/doc-tarball.sh
-${WEBSCRIPTS}/icons2xml_v2.pl
+#${GENTOO_WEB_SCRIPTS}/doc-tarball.sh
+${GENTOO_WEB_SCRIPTS}/icons2xml_v2.pl
# this script is called every 15 minutes now via crontab, so we'll comment it out here
-#${WEBSCRIPTS}/cvs-repo-update.sh
+#${GENTOO_WEB_SCRIPTS}/cvs-repo-update.sh
# this script takes a while (5+ minutes) to run, so leave it near the end
-${WEBSCRIPTS}/distrowatch.sh
+${GENTOO_WEB_SCRIPTS}/distrowatch.sh
# this script also takes a while to run since it uploads the log files to a central server
-${WEBSCRIPTS}/rsync-weblogs.sh
+${GENTOO_WEB_SCRIPTS}/rsync-weblogs.sh
# this script takes the longest of all -- ~1 hour or more. leave it as the *very* last one
-#${WEBSCRIPTS}/pkgs.py
+#${GENTOO_WEB_SCRIPTS}/pkgs.py
echo ">>> Nightly Web update done."
@@ -1,7 +1,7 @@
#!/bin/bash
echo ">>> Starting Web update..."
-#to get GENTOO_WEB_DOCROOT and WEBSCRIPTS defined
+#to get GENTOO_WEB_DOCROOT and GENTOO_WEB_SCRIPTS defined
source ~/.bashrc
#to get all arches in our package listing: